#
# spec file for package python-opencensus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define repo_version 0.11.4-1.1.13

%{?sle15_python_module_pythons}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-opencensus%{psuffix}
Version:        0.11.4
Release:        1.3
Summary:        A stats collection and distributed tracing framework
License:        Apache-2.0
URL:            https://github.com/census-instrumentation/opencensus-python
Source:         https://github.com/census-instrumentation/opencensus-python/archive/v%{repo_version}.tar.gz#/opencensus-python-%{repo_version}-gh.tar.gz
# PATCH-FIX-UPSTREAM opencensus-pr1002-remove-mock.patch -- gh#census-instrumentation/opencensus-python#1002
Patch0:         opencensus-pr1002-remove-mock.patch
# PATCH-FIX-UPSTREAM gh#census-instrumentation/opencensus-python#1243
Patch1:         use-correct-assertion-methods.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-api-core < 3.0.0
Requires:       python-google-api-core >= 1.0.0
Requires:       python-opencensus-context >= 0.1.3
Requires:       python-six >= 1.16
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module opencensus = %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module retrying}
%endif
%python_subpackages

%description
OpenCensus - A stats collection and distributed tracing framework

OpenCensus provides a framework to measure a server's resource usage
and collect performance stats. This repository contains Python related
utilities and supporting software needed by OpenCensus.

%prep
%autosetup -p1 -n opencensus-python-%{repo_version}
# do not hardcode versions
sed -i -e 's:==:>=:g' setup.py

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
# add ext infrastructure
%python_expand mkdir %{buildroot}%{$python_sitelib}/opencensus/ext/
%python_expand cp %{buildroot}%{$python_sitelib}/opencensus/__init__* %{buildroot}%{$python_sitelib}/opencensus/ext
%python_expand [ -e %{buildroot}%{$python_sitelib}/opencensus/__pycache* ] && cp -r %{buildroot}%{$python_sitelib}/opencensus/__pycache* %{buildroot}%{$python_sitelib}/opencensus/ext

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# recursion error in mock != 3; gh#census-instrumentation/opencensus-python#868
donttest="TestGetExporterThreadPeriodic and (test_multiple_producers or test_threaded_export)"
%pytest tests/unit -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%doc CHANGELOG.md README.rst
%license LICENSE
%{python_sitelib}/opencensus
%{python_sitelib}/opencensus-%{version}.dist-info
%endif

%changelog
* Tue Apr  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-correct-assertion-methods.patch:
  * Use non-removed assertion methods.
* Tue Mar 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
* Tue Mar  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.11.4
  * Changed bit-mapping for `httpx` and `fastapi` integrations
- Refresh patches for new version
  * opencensus-pr1002-remove-mock.patch
- Switch package to modern Python Stack on SLE-15
  * Add %%{?sle15_python_module_pythons}
  * Drop %%{?!python_module:%%define python_module() python-%%{**} python3-%%{**}}
* Thu Oct 19 2023 Markéta Machová <mmachova@suse.com>
- update to 0.11.3
  * Updated azure modules
- sorry, six is still needed :(
* Mon Jul 24 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.2:
  * Updated `azure`, `fastapi`,`flask` modules
  * Updated `azure`, `httpx` modules
* Tue Oct 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.11.0
  * Updated `azure`, `context`, `flask`, `requests` modules
- from version 0.10.0
  * Add kwargs to derived gauge (#1135)
- from version 0.9.0
  * Make sure handler.flush() doesn't deadlock (#1112)
- Refresh patches for new version
  * opencensus-pr1002-remove-mock.patch
- Update Requires from setup.py
* Sat Oct 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.8.0
  * Added integration tracking functionality, includes django,
    flask, http-lib, logging, mysql, postgresql, pymongo, pymysql,
    pyramid, requests, sqlalchemy modules (#1065)
  * Support Python 3.8, 3.9 (#1048)
- Releases 0.7.8 to 0.7.13
  * Updated azure, django, flask, requests, grpc, httplib, pyramid
    stackdriver modules
  * Hotfix for breaking change (#915)
- Remove test mock requirement for python3
  * opencensus-pr1002-remove-mock.patch
  * gh#census-instrumentation/opencensus-python#1002
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Provide init in opencensus/ext folder to provide basis
  structure for all the extensions
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to not cycle during testing
* Tue Feb 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.7:
  * Minor fixes
- Fix dependencies
- Enable testsuite
* Wed Jan 29 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.7.6
